import { eResultType } from '../../../../../../../consts';
import { ProcessResponse } from '../../../../../..';
import { aContainer } from '../../container.abstract';
import { DocBinaryInfo, iDocBinaryInfo } from './children';
/**
* Result type of DocBinaryInfoContainer
*/
export type tDocBinaryInfoContainerResultType = eResultType.RFID_BINARY_DATA;
/**
* Result type of DocBinaryInfoContainer
* @type {tDocBinaryInfoContainerResultType[]}
*/
export declare const DocBinaryInfoContainerResultTypes: tDocBinaryInfoContainerResultType[];
/**
* Container for iDocBinaryInfo
*/
export interface iDocBinaryInfoContainer extends aContainer {
    /**
    * Structure is used to store the data reading results from the RFID-chip in
    * a form of a list of the logically separated data groups.
    * @type {iDocBinaryInfo}
    */
    TDocBinaryInfo: iDocBinaryInfo;
    /**
    * Result type stored in this container
    * @type {tDocBinaryInfoContainerResultType}
    */
    result_type: tDocBinaryInfoContainerResultType;
}
/**
* Container for DocBarCodeInfo
*/
export declare class DocBinaryInfoContainer extends aContainer implements iDocBinaryInfoContainer {
    /**
    * Lighting scheme code for the given result (used only for images)
    * @type {number}
    */
    light: number;
    /**
    * @internal
    */
    list_idx: number;
    /**
    * Page index (when working with multi-page document)
    * @type {number}
    */
    page_idx: number;
    /**
    * @internal
    */
    buf_length: number;
    /**
    * Result type stored in this container
    * @type {tDocBinaryInfoContainerResultType}
    */
    result_type: tDocBinaryInfoContainerResultType;
    /**
    * Structure is used to store the data reading results from the RFID-chip in
    * a form of a list of the logically separated data groups.
    * @type {DocBinaryInfo}
    */
    TDocBinaryInfo: DocBinaryInfo;
    /**
    * Creates an instance of DocBinaryInfoContainer from plain object
    *
    * @param {unknown} input - plain object
    * @returns {DocBinaryInfoContainer}
    */
    static fromPlain: (input: unknown) => DocBinaryInfoContainer;
    /**
    * Get DocBinaryInfoContainer from ProcessResponse
    * @param {ProcessResponse} input - ProcessResponse object
    * @param {boolean} asPlain - return as plain object
    * @returns {(iDocBinaryInfoContainer | DocBinaryInfoContainer)[]}
    */
    static fromProcessResponse(input: ProcessResponse, asPlain: true): iDocBinaryInfoContainer[];
    static fromProcessResponse(input: ProcessResponse, asPlain?: false): DocBinaryInfoContainer[];
    /**
    * Check if the given instance is a valid DocBinaryInfoContainer
    *
    * @param {DocBinaryInfoContainer} instance - instance to check
    * @throws {DocReaderTypeError}
    * @returns {true | never}
    */
    static validate: (instance: DocBinaryInfoContainer) => true | never;
}
